@@ -6,12 +6,11 @@ BEGIN {
   $Dist::Zilla::MetaProvides::ProvideRecord::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::MetaProvides::ProvideRecord::VERSION = '1.14000001';
+  $Dist::Zilla::MetaProvides::ProvideRecord::VERSION = '1.15000000';
 }
 
 # ABSTRACT: Data Management Record for MetaProvider::Provides Based Class
 
-# $Id:$
 use Moose;
 use MooseX::Types::Moose             (':all');
 use Dist::Zilla::MetaProvides::Types (':all');
@@ -19,6 +18,7 @@ use Dist::Zilla::MetaProvides::Types (':all');
 use namespace::autoclean;
 
 
+
 has version => ( isa => ModVersion, is => 'ro', required => 1 );
 
 
@@ -52,8 +52,8 @@ no Moose;
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -62,7 +62,18 @@ Dist::Zilla::MetaProvides::ProvideRecord - Data Management Record for MetaProvid
 
 =head1 VERSION
 
-version 1.14000001
+version 1.15000000
+
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Dist::Zilla::MetaProvides::ProvideRecord",
+    "interface":"class",
+    "inherits":"Moose::Object"
+}
+
+
+=end MetaPOD::JSON
 
 =head1 ATTRIBUTES
 
@@ -107,10 +118,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric.
+This software is copyright (c) 2013 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
